{% extends 'admin/base_site.html' %}

{% block content %}
  <div id="content-main">
    <h2>Clear cache</h2>
    <form method="post" action=".">
      {% csrf_token %}
      {{ form.as_p }}
      <div class="submit-row">
        <input type="submit" class="button" name="clearcache" value="Clear cache now 💣">
      </div>
    </form>
  </div>
{% endblock %}
